@@ -250,6 +250,7 @@ class Presto(Dialect):
         exp.FileFormat: _fileformat_sql,
         exp.If: _if_sql,
         exp.JSONPath: lambda self, e: f"JSON_EXTRACT({self.sql(e, 'this')}, {self.sql(e, 'path')})",
+        exp.RegexLike: lambda self, e: f"REGEXP_LIKE({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.StrPosition: _str_position_sql,
         exp.StrToTime: lambda self, e: f"DATE_PARSE({self.sql(e, 'this')}, {self.sql(e, 'format')})",
         exp.StrToUnix: lambda self, e: f"TO_UNIXTIME(DATE_PARSE({self.sql(e, 'this')}, {self.sql(e, 'format')}))",
@@ -275,6 +276,7 @@ class Presto(Dialect):
         'DATE_PARSE': lambda args: exp.StrToTime(this=args[0], format=args[1]),
         'FROM_UNIXTIME': lambda args: exp.UnixToTime(this=args[0]),
         'JSON_EXTRACT': lambda args: exp.JSONPath(this=args[0], path=args[1]),
+        'REGEXP_LIKE': lambda args: exp.RegexLike(this=args[0], expression=args[1]),
         'STRPOS': lambda args: exp.StrPosition(this=args[0], substr=args[1]),
         'TO_UNIXTIME': lambda args: exp.TimeToUnix(this=args[0]),
     }
