@@ -402,6 +402,11 @@ class Map(Func):
     arg_types = {'keys': True, 'values': True}
 
 
+class RegexLike(Func):
+    token_type = TokenType.RLIKE
+    arg_types = {'this': True, 'expression': True}
+
+
 class StrPosition(Func):
     arg_types = {'this': True, 'substr': True, 'position': False}
 
